"""
Name: Connect to the Google Analytics API
Developer: Matt Clarke
Date: June 8, 2020
Description: Authenticates with the Google Analytics API using a client secrets JSON key file
and returns a Google Analytics service for use in other functions.
"""

import socket
import os.path
from googleapiclient.discovery import build
from oauth2client.service_account import ServiceAccountCredentials

# Prevent "The read operation timed out" errors
socket.setdefaulttimeout(500)


def get_service(keyfile_path, verbose=False):
    """Return a service to communicate with the Google Analytics API
       using settings from the configuration file.

    :param keyfile_path - Path to client_secrets.json
    :param verbose: Set to True to see messages
    """

    if verbose:
        print('Attempting connection')

    if not os.path.exists(keyfile_path):
        print('Keyfile not found')
        exit()

    else:

        try:
            credentials = ServiceAccountCredentials.from_json_keyfile_name(keyfile_path,
                                                                           scopes="https://www.googleapis.com/auth"
                                                                                  "/analytics.readonly")
            service = build("analytics", "v3", credentials=credentials)

            if verbose:
                print('Connected successfully')

            return service

        except Exception as e:

            if verbose:
                print('Connection failed: \
                Ensure your keyfile is correct and you have added the email to your Google Analytics account.')

            return e



from setuptools import setup

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='gapandas',
    packages=['gapandas'],
    version='0.16',
    license='MIT',
    description='GAPandas is a Python package for accessing Google Analytics API data using Pandas for use in models, '
                'reports or visualisations',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Matt Clarke',
    author_email='matt@flyandlure.org',
    url='https://github.com/flyandlure/gapandas',
    download_url='https://github.com/flyandlure/gapandas/archive/master.zip',
    keywords=['python', 'google analytics', 'ga', 'pandas', 'universal analytics'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
    ],
    install_requires=['pandas', 'google-api-python-client', 'oauth2client']
)
